OC.L10N.register(
    "logreader",
    {
    "Error parsing log" : "Napló feldolgozási hiba",
    "Cased by " : "Létrehozta",
    "Copy" : "Másolás",
    "Copy raw" : "Másolás eredeti formába",
    "Copy formatted" : "Másolás formázva",
    "No server logs" : "Nincsenek kiszolgálónaplók",
    "One or more entries are hidden by the log level filter" : "Egy vagy több bejegyzés elrejtve a naplózási szint szűrő miatt",
    "Everything is working fine" : "Minden rendben működik",
    "Log levels" : "Naplózási szintek",
    "Log content" : "Naplótartalom",
    "Live update" : "Élő frissítés",
    "Download logs" : "Naplók letöltése",
    "Logging" : "Naplózás",
    "Log Reader" : "Naplóolvasó",
    "A log reader for Nextcloud" : "Egy naplóolvasó a Nextcloudhoz",
    "Log reader for Nextcloud" : "Naplóolvasó a Nextcloudhoz"
},
"nplurals=2; plural=(n != 1);");
